pub enum ConfigError {
NotFound(String),
Io {
path: String,
source: Error,
},
Parse {
path: String,
message: String,
},
KeyNotFound(String),
SectionNotFound(String),
FeatureNotEnabled {
feature: &'static str,
},
Other(String),
}Expand description
All errors that can occur in config-get.
Variants
NotFound(String)
No configuration file was found in any of the searched paths.
Io
The file could not be read from disk.
Parse
The file content could not be parsed.
Fields
KeyNotFound(String)
A required key was not found in the config.
SectionNotFound(String)
The requested section was not found.
FeatureNotEnabled
A feature required to handle this format is not enabled.
Other(String)
Generic / unexpected error.